@@ -26,7 +26,7 @@ class CreateReactLoader(object):
 
     @property
     def asset_path(self):
-        if self.is_dev and not self.manifest_path:
+        if self.is_dev:
             return self.config['FRONT_END_SERVER'].strip('/') + "/"
         return "/"
 
@@ -56,9 +56,7 @@ class CreateReactLoader(object):
                 'the asset-manifest file in the build directory and the path is correct?')
 
     def get_assets(self):
-        if self.manifest_path:
-            return self.get_prod_assets()
-        if self.is_dev:
+        if self.is_dev and not self.manifest_path:
             return self.get_dev_assets()
         return self.get_prod_assets()
 
