@@ -17,20 +17,26 @@ def render_bundle_js(config="DEFAULT"):
     tags = utils.get_as_tags(extension='js', config=config)
     return mark_safe('\n'.join(tags))
 
+@register.simple_tag
+def render_bundle_src_css(config="DEFAULT"):
+    tags = utils.get_src_files(extension='css', config=config)
+    return tags
+
 
 @register.simple_tag
-def render_bundle_page_css(page_name="main", config=None):
-    if not config:
-        config = "DEFAULT"
+def render_bundle_src_js(config="DEFAULT"):
+    tags = utils.get_as_tags(extension='js', config=config)
+    return tags
 
+
+@register.simple_tag
+def render_bundle_page_css(page_name="main", config="DEFAULT"):
     tags = utils.get_tags_per_page(extension='css', page_name=page_name, config=config)
     return mark_safe('\n'.join(tags))
 
 
 @register.simple_tag
-def render_bundle_page_js(page_name="main", config=None):
-    if not config:
-        config = "DEFAULT"
+def render_bundle_page_js(page_name="main", config="DEFAULT"):
     tags = utils.get_tags_per_page(extension='js', page_name=page_name, config=config)
     return mark_safe('\n'.join(tags))
 
@@ -45,3 +51,15 @@ def render_asset_page_js(page_name="main", manifest_path=None):
     tags = utils.get_tags_per_page(extension='js', page_name=page_name, manifest_path=manifest_path)
     return mark_safe('\n'.join(tags))
 
+
+
+@register.simple_tag
+def render_bundle_page_src_css(page_name="main", config="DEFAULT"):
+    tags = utils.get_src_files(extension='css', page_name=page_name, config=config)
+    return mark_safe('\n'.join(tags))
+
+
+@register.simple_tag
+def render_bundle_page_src_js(page_name="main", config="DEFAULT"):
+    tags = utils.get_src_files(extension='js', page_name=page_name, config=config)
+    return mark_safe('\n'.join(tags))
\ No newline at end of file
