@@ -28,9 +28,14 @@ def get_loader(config_name, manifest_path=None):
 
 def _filter_by_extension(bundle, extension):
     '''Return only files with the given extension'''
-    for chunk in bundle:
-        if chunk.endswith('.{0}'.format(extension)):
-            yield chunk
+    if isinstance(bundle, list):
+        for chunk in bundle:
+            if chunk.endswith('.{0}'.format(extension)):
+                yield chunk
+    else:
+        if bundle.endswith('.{0}'.format(extension)):
+            yield bundle
+
 
 
 def _get_bundle(extension, loader):
